/**
  *  \file flak/dlg-select.cc
  *
  *  (c) 2001-2005 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "flak/dlg-select.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "ui/uiglobal.h"
#include "game/player.h"
#include "ui/util.h"

FlakVcrSelector::FlakVcrSelector(FlakVcrDatabase& db)
    : db(db), current(0)
{ }

FlakVcrSelector::~FlakVcrSelector()
{ }

void
FlakVcrSelector::draw(GfxCanvas& can, UpdateInfo& ui)
{
    // FIXME: this is too simple
    UISkin& s = getSkin();
    FlakVcrEntry& b = db.getBattle(current);

    string_t text = format(_("Battle %d of %d: %d ships in %d groups\n"
                             "  Location: (%d,%d)\n"))
                                 << (current+1)
                                 << db.getVcrCount()
                                 << b.getNumShips()
                                 << b.getNumFleets()
                                 << b.getPositionX()
                                 << b.getPositionY();
    int n = getExtent().h / font_heights[FONT_NORMAL] - 2;
    if (n > b.getNumShips())
        n = b.getNumShips();
    for (int i = 0; i < n; ++i) {
        FlakShip& sh = b.getBattle().getShipByNumber(i);
        if (sh.isPlanet())
            text += format(_("%s planet %d: %s\n"))
                << getAdjName(sh.data.player)
                << sh.data.id
                << getBasicStringN(sh.data.name, 20);
        else
            text += format(_("%s ship %d: %s\n"))
                << getAdjName(sh.data.player)
                << sh.data.id
                << getBasicStringN(sh.data.name, 20);
    }

    s.startDraw();
    s.drawBackground(can, getExtent());
    s.setSolid(false);
    s.setColor(UIColor::tc_Static);
    s.getParameters().font = fonts[FONT_NORMAL];
    outTextFormattedF(can, s.getParameters(), getExtent().x, getExtent().y,
                      getExtent().w, getExtent().h / font_heights[FONT_NORMAL],
                      text);
    ui.update(getExtent());
}

void
FlakVcrSelector::getLayoutInfo(LayoutInfo& info)
{
    // FIXME: this is too simple...
    info.flags = 0;
    info.min_size = info.pref_size =
        GfxPoint(30 * font_ems[FONT_NORMAL], 10 * font_heights[FONT_NORMAL]);
}

void
FlakVcrSelector::next(int)
{
    setCurrent(getCurrent()+1);
}

void
FlakVcrSelector::previous(int)
{
    setCurrent(getCurrent()-1);
}

void
FlakVcrSelector::setCurrent(int n)
{
    if (n >= db.getVcrCount())
        n = db.getVcrCount()-1;
    if (n < 0)
        n = 0;

    if (n != current) {
        current = n;
        sig_scrolled.raise();
        drawWidget();
    }
}

