/**
  *  \file flak/flak-db.cc
  *
  *  (c) 2001-2005 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <cstring>
#include "flak/flak-db.h"
#include "util/nls.h"
#include "util/except.h"
#include "util/misc.h"

/****************************** FlakVcrEntry *****************************/

/** Constructor. Initialize this VCR entry from data of */
FlakVcrEntry::FlakVcrEntry(const Buffer<char>& data)
{
    battle.loadFromStream(data, header);
}

FlakVcrEntry::~FlakVcrEntry()
{ }

/**************************** FlakVcrDatabase ****************************/

/** Constructor. Create empty FLAK VCR Database. */
FlakVcrDatabase::FlakVcrDatabase()
{ }

/** Destructor. */
FlakVcrDatabase::~FlakVcrDatabase()
{
    safeClear(battles);
}

/** Read one battle from given stream.
    \return true if successful, false on error. */
bool
FlakVcrDatabase::readOneBattle(Stream& s)
{
    Buffer<char> data;
    data.ensureSize(4);
    if (s.read(data.ptr(), 4) != 4)
        return false;
    uint32 size = getUint32(data.ptr());
    data.ensureSize(size);
    if (s.read(data.ptr()+4, size-4) != size-4)
        return false;

    safeAppend(battles, new FlakVcrEntry(data));
    return true;
}

/** Load battles from a file. Battles will be appended to this
    database. */
void
FlakVcrDatabase::loadFromFile(Stream& s)
{
    if (!getStructure(s, last_header))
        throw FileFormatException(_("File damaged (missing header)"));
    if (std::memcmp(last_header.magic, FLAK_MAGIC, sizeof(FLAK_MAGIC)) != 0)
        throw FileFormatException(_("File damaged (missing header)"));
    if (last_header.filefmt_version != 0)
        throw FileFormatException(_("Unknown file format version"));

    for (int i = 0; i < last_header.num_battles; ++i) {
        if (!readOneBattle(s))
            throw FileFormatException(_("File damaged (truncated)"));
    }
}
