/**
  *  \file game/global-bb.cc
  *  \brief Chart Bounding Boxes
  *
  *  (c) 2001-2005 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/global.h"

/******************************* GChartBBox ******************************/

/** Initialize bounding box from game turn.
    \todo currently this is only a dummy */
void
GChartBBox::initFromTurn(GGameTurn& trn)
{
    min = GPoint(chart_conf.xmin, chart_conf.ymin);
    max = GPoint(chart_conf.xmax, chart_conf.ymax);

    initMinZoom();
    initMaxZoom();
}

/** Compute minimum zoom level. The minimum zoom is a soft limit;
    below the limit, the scrolling map is replaced by a fixed one. */
void
GChartBBox::initMinZoom()
{
    /* Minimum zoom. At zoom smaller 1:N, switch to overview chart */
    min_zoom = 2;
    // FIXME: dummy
    // CheckMinZoom(SCREEN_WIDTH DIV 2, ChartBX1-ChartConf.CenterX);
    // CheckMinZoom(SCREEN_WIDTH DIV 2, ChartConf.CenterX-ChartBX0);
    // CheckMinZoom((SCREEN_HEIGHT-80) DIV 2, ChartBY1-ChartConf.CenterY);
    // CheckMinZoom((SCREEN_HEIGHT-80) DIV 2, ChartConf.CenterY-ChartBY0);
    if (min_zoom > MAX_ZOOM)
        min_zoom = MAX_ZOOM;
}

/** Compute maximum zoom level. The maximum zoom level is a hard
    limit; under no conditions the hard limit may be exceeded to avoid
    integer overflow. */
void
GChartBBox::initMaxZoom()
{
    max_zoom = INT_MAX / std::max(max.x, max.y);
    if (max_zoom > MAX_ZOOM)
        max_zoom = MAX_ZOOM;
}
