/**
  *  \file game/objtypes.h
  *  \brief Object Type
  *
  *  (c) 2001-2005 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_OBJTYPES_H
#define PCC_V2_GAME_OBJTYPES_H

#include "cpluslib/string.h"
#include "cpluslib/sigslot.h"

class GGameTurn;
class GObject;

class GObjectType {
    GObjectType(const GObjectType&);
    GObjectType& operator=(const GObjectType&);
 protected:
    GGameTurn& trn;
    int current;
    int count;
    int max;
 public:
    GObjectType(int max, GGameTurn& trn);
    virtual ~GObjectType();

    virtual void init();

    /** Check whether an object of the given Id exists.
        \param index Id number to test. */
    virtual bool isExistant(int index) = 0;

    /** Get class name. Should return a name which identifies this
        object class, e.g. "Ship". */
    virtual string_t getClassName() = 0;

    /** Get object. Should return the identified object.
        \param index Id number
        \pre isExistant(index) */
    virtual GObject& getObject(int index) = 0;

    virtual int getNext(int index, bool mark);
    virtual int getPrev(int index, bool mark);

    virtual void setCurrent(int index);

    /** Get currently-selected object Id. */
    int getCurrent() const
        { return current; }

    /** Get number of objects of this type. */
    int getCount() const
        { return count; }

    /** Get associated turn. */
    GGameTurn& getTurn() const
        { return trn; }

    /** Signal: Position changed. Raised when a different object is
        selected. */
    Signal1<int> sig_pos_changed;
};

#endif
