/**
  *  \file util/nls.h
  *  \brief Definitions for National Language Support
  *
  *  (c) 2001-2005 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UTIL_NLS_H
#define PCC_V2_UTIL_NLS_H

#include <vector>
#include <map>
#include <cstddef>

#define _(x)  translate(x)
#define N_(x) (x)

class Stream;

class StringTranslator {
    /** \name Memory Pools */
    //@{
    /** Minimum size allocated for a pool entry. */
    static const std::size_t MIN_POOL = 8192;

    /** Pointer to first entry of current pool. */
    char* current_pool;

    /** Number of bytes free in current pool. */
    std::size_t current_free;

    char* allocPool(std::size_t size);

    /** All allocated pools. */
    std::vector<char*> pools;
    //@}
    
    /** Translation data. Mapping original -> translated data. */
    std::map<const char*, const char*> data;

    StringTranslator(const StringTranslator&);
    StringTranslator& operator=(const StringTranslator&);
 public:
    StringTranslator();
    ~StringTranslator();

    const char* translate(const char* in) const;
    void        addTranslation(const char* ori, const char* translated);
};

const char* translate(const char* in);
void loadLanguageDatabase(Stream* p);
void loadLanguageDatabase(const char* lang);

void initNLS();

#endif
